@@ -1,8 +1,6 @@
 package Spork::Config;
-use strict;
-use warnings;
-use Spoon::Config '-base';
-use Spoon::Installer '-base';
+use Kwiki::Config -base;
+use mixin 'Spoon::Installer';
 
 const class_id => 'config';
 
@@ -16,22 +14,33 @@ sub default_configs {
 }
 
 sub default_config {
-    {
+    my $config = super;
+    $config->{slides_file} = 'Spork.slides';
+    $config->{template_directory} = 'template/tt2';
+    $config->{template_path} = [ 'template/tt2' ];
+    return $config;
+}
+
+sub default_classes {
+    (
         config_class => 'Spork::Config',
+        registry_class => 'Spork::Registry',
         hub_class => 'Spork::Hub',
         formatter_class => 'Spork::Formatter',
         template_class => 'Spork::Template::TT2',
         command_class => 'Spork::Command',
         slides_class => 'Spork::Slides',
-
-        slides_file => 'Spork.slides',
-        template_directory => 'template/tt2',
-        template_path => [ 'template/tt2' ],
-    }
+        # For Kwiki Plugins:
+        cgi_class => 'Kwiki::CGI',
+        pages_class => 'Kwiki::Pages',
+        preferences_class => 'Kwiki::Preferences',
+        css_class => 'Kwiki::CSS',
+        javascript_class => 'Kwiki::Javascript',
+        cache_class => 'Kwiki::Cache',
+        kwiki_command_class => 'Kwiki::Command',
+    )
 }
 
-1;
-
 __DATA__
 
 =head1 NAME
@@ -164,6 +173,19 @@ A list of template directories to be used by the template processing class.
 
 =back
 
+=head1 AUTHOR
+
+Brian Ingerson <INGY@cpan.org>
+
+=head1 COPYRIGHT
+
+Copyright (c) 2004, 2005. Brian Ingerson. All rights reserved.
+
+This program is free software; you can redistribute it and/or modify it
+under the same terms as Perl itself.
+
+See http://www.perl.com/perl/misc/Artistic.html
+
 =cut
 
 __config.yaml__
@@ -185,7 +207,7 @@ copyright_string: Copyright &copy; 2004 Brian Ingerson
 
 banner_bgcolor: hotpink
 show_controls: 1
-mouse_controls: 1
+mouse_controls: 0
 image_width: 350
 auto_scrolldown: 1
 logo_image: logo.png
@@ -206,3 +228,6 @@ start_command: open slides/start.html
 
 template_class: Spork::Template::TT2
 formatter_class: Spork::Formatter
+
+# plugin_classes:
+# - Kwiki::PerlMode
